Santhosh has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/221565

Change subject: Rename the getLink method to avoid confusion with CXLink.getLink
......................................................................

Rename the getLink method to avoid confusion with CXLink.getLink

Bug: T104122
Change-Id: I1d76c0c9bb1b580175ee6d4146a5c6147f0fb1c5
---
M modules/tools/ext.cx.tools.link.js
1 file changed, 3 insertions(+), 3 deletions(-)


  git pull 
ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/ContentTranslation 
refs/changes/65/221565/1

diff --git a/modules/tools/ext.cx.tools.link.js 
b/modules/tools/ext.cx.tools.link.js
index c471117..04e6558 100644
--- a/modules/tools/ext.cx.tools.link.js
+++ b/modules/tools/ext.cx.tools.link.js
@@ -16,13 +16,13 @@
        };
 
        /**
         * Get the link data for a given title and language.
thumbnail image.
         * @param {mediawiki.Api} api
         * @param {string} title
         * @param {string} language
         * @return {jQuery.Promise}
         */
-       function getLink( api, title, language ) {
+       function getLinkDetails( api, title, language ) {
                var request;
 
                // Normalize the title
@@ -316,7 +316,7 @@
                }
 
                api = this.siteMapper.getApi( language );
-               return getLink( api, title, language ).then( function ( 
response ) {
+               return getLinkDetails( api, title, language ).then( function ( 
response ) {
                        var pageId;
 
@@ -16,13 +16,13 @@
 
        /**
-        * Get the link data for a given title and language.
+        * Get the link details for a given title and language such as page 
thumbnail image.
         * @param {mediawiki.Api} api
                        pageId = Object.keys( response.query.pages )[ 0 ];

-- 
To view, visit https://gerrit.wikimedia.org/r/221565
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I1d76c0c9bb1b580175ee6d4146a5c6147f0fb1c5
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/ContentTranslation
Gerrit-Branch: master
Gerrit-Owner: Santhosh <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to